@@ -14,7 +14,7 @@ our %EXPORT_TAGS = ('all' => [ qw() ]) ;
 our @EXPORT_OK = ( @{$EXPORT_TAGS{'all'} } ) ;
 our @EXPORT = qw(DumpTree DumpTrees CreateChainingFilter);
 
-our $VERSION = '0.23' ;
+our $VERSION = '0.24' ;
 
 my $WIN32_CONSOLE ;
 
@@ -159,6 +159,12 @@ my %overrides         =  @_ ;
 
 $title = defined $title ? $title : '' ;
 
+unless(defined $structure_to_dump)
+	{
+	my ($package, $file_name, $line) = caller() ;
+	return("You asked DumpeTree to dump 'undef' with title: '$title' @ '$file_name:$line'.\n") ;
+	}
+
 if(exists $overrides{NO_PACKAGE_SETUP} && $overrides{NO_PACKAGE_SETUP})
 	{
 	return(TreeDumper($structure_to_dump, {TITLE => $title, %setup, %overrides})) ;
@@ -172,7 +178,7 @@ else
 #-------------------------------------------------------------------------------
 sub DumpTrees
 {
-my @trees           = grep {'ARRAY' eq ref $_} @_ ;
+my @trees            = grep {'ARRAY' eq ref $_} @_ ;
 my %global_overrides = grep {'ARRAY' ne ref $_} @_ ;
 
 my $dump = '' ;
@@ -180,8 +186,18 @@ my $dump = '' ;
 for my $tree (@trees)
 	{
 	my ($structure_to_dump, $title, %overrides) = @{$tree} ;
-	
-	$dump .= DumpTree($structure_to_dump, $title, %global_overrides, %overrides) ;
+	$title = defined $title ? $title : '' ;
+		
+	if(defined $structure_to_dump)
+		{
+		$dump .= DumpTree($structure_to_dump, $title, %global_overrides, %overrides) ;
+		}
+	else
+		{
+		my ($package, $file_name, $line) = caller() ;
+		$dump .= "DumpTrees can't dump 'undef' with title: '$title' @ '$file_name:$line'.\n" ;
+		}
+		
 	}
 	
 return($dump) ;
@@ -199,6 +215,7 @@ my $levels_left      = shift || [] ;
 
 my $tree_type = ref $tree ;
 confess "TreeDumper can only display objects passed by reference!\n" if('' eq  $tree_type) ;
+
 #~ # if we want to handle scalars passed to the dumper
 #~ if('' eq  $tree_type)
 	#~ {
@@ -475,7 +492,11 @@ for (my $nodes_left = $#nodes_to_display ; $nodes_left >= 0 ; $nodes_left--)
 				
 			$tag = 'H' ;
 			$perl_address = "$element" if($setup->{DISPLAY_PERL_ADDRESS}) ;
-			$default_element_rendering = ' (no elements)' unless %{$element} ;
+			
+			if(! %{$element} && ! $setup->{NO_NO_ELEMENTS})
+				{
+				$default_element_rendering = ' (no elements)' ;
+				}
 			
 			if(%{$element} && ($setup->{MAX_DEPTH} == $level + 1) && $setup->{DISPLAY_NUMBER_OF_ELEMENTS_OVER_MAX_DEPTH})
 				{
@@ -517,7 +538,11 @@ for (my $nodes_left = $#nodes_to_display ; $nodes_left >= 0 ; $nodes_left--)
 				
 			$tag = 'A' ;
 			$perl_address = "$element" if($setup->{DISPLAY_PERL_ADDRESS}) ;
-			$default_element_rendering = ' (no elements)' unless @{$element} ;
+			
+			if(! @{$element} && ! $setup->{NO_NO_ELEMENTS})
+				{
+				$default_element_rendering = ' (no elements)' ;
+				}
 			
 			if(@{$element} && ($setup->{MAX_DEPTH} == $level + 1) && $setup->{DISPLAY_NUMBER_OF_ELEMENTS_OVER_MAX_DEPTH})
 				{
@@ -1404,6 +1429,10 @@ the scalar values.
 
   DumpTree(\$s, 'Cells:', QUOTE_VALUES=> 1) ;
   
+=head2 NO_NO_ELEMENTS
+
+If this option is set, PBS will not add 'no elements' to empty hashes and arrays
+
 =head2 NO_OUTPUT
 
 This option suppresses all output generated by Data::TreeDumper. 
